/*********************************************************************/
/* AUTHOR:  Evan Easton                                              */
/*          email: eeaston@maroon.tc.umn.edu                         */
/* NAME: OBJECTS.INC                                                 */
/*   This in an include file for REEROOM.POV                         */
/*********************************************************************/

/* THE TABLE */
#declare Table=union{
   box{ <-7,-0.2,-10>,<7,0,10>               texture{ Wood1 } }
   box{ <-6.5,-0.8,-9.5>,<6.5,-0.2,-9.3>     texture{ Wood1 rotate <90,0,90> } }
   box{ <-6.5,-0.8,9.3>,<6.5,-0.2,9.5>       texture{ Wood1 rotate <90,0,90> } }
   box{ <-6.5,-0.8,-9.3>,<-6.3,-0.2,9.3>     texture{ Wood1 rotate z*90 } }
   box{ <6.3,-0.8,-9.3>,<6.5,-0.2,9.3>       texture{ Wood1 rotate z*90 } }
   box{ <-6.3,-10,-9.3>,<-5.8,-0.2,-8.8>     texture{ Wood1 rotate x*90 } }
   box{ <5.8,-10,-9.3>,<6.3,-0.2,-8.8>       texture{ Wood1 rotate x*90 } }
   box{ <-6.3,-10,8.8>,<-5.8,-0.2,9.3>       texture{ Wood1 rotate x*90 } }
   box{ <5.8,-10,8.8>,<6.3,-0.2,9.3>         texture{ Wood1 rotate x*90 } }
}

/* THE LAMP */
#declare Lamp=union{
   sphere{                                                
      <0,1,0>,1.2
      scale <0.9,1.0,0.9>
      pigment{ color DarkSlateBlue }
      finish{ specular 1   roughness 0.0001  reflection 0.15 }
   }
   cone{
      <0,2,0>,1.75,<0,3.875,0>,0.75
      open
      no_shadow
      pigment{ color Tan filter 0.0 }
      normal{ bumps 0.25 scale <0.01,0.01,0.01> }
      finish{ refraction 1.0 ior 1.0 }
   }
   cone{
      <0,2,0>,1.749,<0,3.875,0>,0.749
      open
      pigment{ color Tan filter 0.75 }
      finish{ refraction 1.0 ior 1.0 }
   }
   torus{ 
      1.75,0.005
      pigment{ color Tan filter 0.2 }
      finish{ refraction 1.0 ior 1.0 }
      translate <0,2,0>
   }
   torus{
      0.75,0.005
      pigment{ color Tan filter 0.2 }
      finish{ refraction 1.0 ior 1.0 }
      translate <0,3.875,0>
   }
//   light_source{         // Use this point source for faster rendering.
//      <0,3,0>
//      color White
//   }
   light_source{           // Use this area light for a nicer looking picture.
      <0,3.0,0>
      color red 1.0 green 1.0 blue 0.9
      area_light <1,0,0>,<0,0.3,0>,1,9
      adaptive 2
      jitter
   }
}

/* WINDOW SHADE */
#declare Shade=union{
   cylinder{
      <0,19.2,-0.7>,<7,19.2,-0.7>,0.3
      pigment{ color White }
      finish{ Dull }
   }
   triangle{
      <0,19.2,-0.4>,<0,17,-0.4>,<7,17,-0.4>
      pigment{ color White filter 0.1}
      finish{ Dull }
   }
   triangle{
      <0,19.2,-0.4>,<7,19.2,-0.4>,<7,17,-0.4>
      pigment{ color White filter 0.1 }
      finish{ Dull }
   }
   cylinder{
      <0,16.8,-0.4>,<7,16.8,-0.4>,0.2
      pigment{ color White }
      finish{ Dull }
   }
   cylinder{
      <3.5,16.6,-0.4>,<3.5,12.5,-0.4>,0.05
      pigment{ color Brown }
      finish{Dull }
   }
   cone{
      <3.5,12.5,-0.4>,0.075,<3.5,12.2,-0.4>,0.15
      pigment{ color Brown }
      finish{Dull}
   }
   object{
      XYSquare
      scale<1.3,0.4,1>
      rotate y*90
      translate<-0.01,19,0.4>
      pigment{ color Gray20 }
      finish{ Metal }
   }
   object{
      XYSquare
      scale<1.3,0.4,1>
      rotate y*90
      translate<7.01,19,0.4>
      pigment{ color Gray20 }
      finish{ Metal }
   }
}

/* WINDOW GLASS */
#declare Panes=box{
   <0.4,10.4,0.45>,<6.6,19.0,0.55>
   texture{ Glass }
}

/* WINDOW */
#declare Window=union{
   box{
      <0,10,0>,<7,10.4,1>
      texture{ Wood1 rotate y*90 }
   }
   box{
      <0,10.4,0>,<0.4,19,1>
      texture{ Wood1 rotate <90,90,0> }
   }
   box{
      <6.6,10.4,0>,<7,19,1>
      texture{ Wood1 rotate <90,90,0> }
   }
   box{
      <0,19,0>,<7,19.4,1>
      texture{ Wood1 rotate y*90 }
   }
   cylinder{
      <3.5,10.4,0.5>,<3.5,19,0.5>,0.1
      texture{ Wood1 rotate x*90 }
   }
   box{
      <0.4,14.6,0.35>,<6.6,14.8,0.65>
      texture{ Wood1 rotate y*90 }
   }
   union{
      box{ <0,9.4,-1.0>,<7,9.98,0.5> }
      cylinder{
         <0,0,0>,<7,0,0>,0.29
         scale <1,1,0.25>
         translate <0,9.69,-1.0>
      }
      texture{ Wood1 rotate y*90 }
   }
   object{ Shade }
   object{ Panes }
   bounded_by{ box{ <-0.02,9.69,-1.29>,<7.02,19.41,1.01> } }
}

/* WALLS and CEILING */
#declare WESTWall=union{
   union{
      triangle{ <-25,0,-30>,<-25,10,20>,<-25,10,-30> }
      triangle{ <-25,0,-30>,<-25,10,20>,<-25,0,20> }
      triangle{ <-25,19.4,-30>,<-25,22,20>,<-25,19.4,20> }
      triangle{ <-25,19.4,-30>,<-25,22,20>,<-25,22,-30> }
      triangle{ <-25,10,-30>,<-25,19.4,0>,<-25,19.4,-30> }
      triangle{ <-25,10,-30>,<-25,19.4,0>,<-25,10,0> }
      triangle{ <-25,10,7>,<-25,19.4,20>,<-25,19.4,7> }
      triangle{ <-25,10,7>,<-25,19.4,20>,<-25,10,20> }
      texture{ WallTexture }
   }
   object{
      Window
      rotate y*-90
      translate <-24.5,0,0>
   }
}
#declare EASTWall=union{
   triangle{ <15,0,-30>,<15,22,20>,<15,22,-30> }
   triangle{ <15,0,-30>,<15,22,20>,<15,0,20> }
   texture{ WallTexture  }
}
#declare NORTHWall=union{
   triangle{ <-25,0,20>,<15,22,20>,<15,0,20> }
   triangle{ <-25,0,20>,<15,22,20>,<-25,22,20> }
   texture{ WallTexture }
}
#declare Ceiling=union{
   triangle{ <-25,22,-30>,<15,22,20>,<15,22,-30> }
   triangle{ <-25,22,-30>,<15,22,20>,<-25,22,20> }
   texture{ CeilingTexture }
}



/* FLOOR */
#declare Plank=union{
   triangle{ <0,0,0>,<19.95,0,0>,<0,0,1.95> }
   triangle{ <0,0,1.95>,<19.95,0,0>,<19.95,0,1.95> }
   texture{ FloorWood rotate y*90 }
}
#declare HalfPlank=union{
   triangle{ <0,0,0>,<9.95,0,0>,<0,0,1.95> }
   triangle{ <0,0,1.95>,<9.95,0,0>,<9.95,0,1.95> }
   texture{ FloorWood rotate y*90 }
}
#declare TwoStrip=union{
   object{ Plank translate <-5,0,0> }
   object{ Plank translate <-25,0,0> }
   object{ HalfPlank translate <-25,0,2> }
   object{ Plank translate <-15,0,2> }
   object{ HalfPlank translate <5,0,2> }
}
#declare Moulding=union{
   cylinder{
      <0,0,-30>,<0,0,20>,0.6
      scale <0.3,1,1>
      translate <-25,0,0>
      texture{ FloorWood }
   }
   cylinder{
      <-25,0,0>,<15,0,0>,0.6
      scale <1,1,0.3>
      translate <0,0,20>
      texture{ FloorWood rotate y*90 }
   }
   cylinder{
      <0,0,-30>,<0,0,20>,0.6
      scale <0.3,1,1>
      translate <15,0,0>
      texture{ FloorWood }
   }
}
#declare Floor=union{
   object{ TwoStrip }
   object{ TwoStrip translate <0,0,4> }
   object{ TwoStrip translate <0,0,8> }
   object{ TwoStrip translate <0,0,12> }
   object{ TwoStrip translate <0,0,16> }
   object{ TwoStrip translate <0,0,-4> }
   object{ TwoStrip translate <0,0,-8> }
   object{ TwoStrip translate <0,0,-12> }
//   object{ TwoStrip translate <0,0,-16> }  //  These would only be necessary if you
//   object{ TwoStrip translate <0,0,-20> }  // wanted to expand the scene and use more
//   object{ TwoStrip translate <0,0,-14> }  // of the room.
//   object{ TwoStrip translate <0,0,-28> }
   object{ Moulding }
   bounded_by{ box{ <-20,-0.1,-30>,<15,0.61,20> } }
}

/* THE OUTDOORS */
#declare Outside=union{
   sphere{
      <0,0,0>,3000
      pigment{ color Gray70 }
      finish{
         crand 0.05
         ambient OutsideAmbiance
         diffuse 0.1
      }
   }
   plane{
      y,-0.2
      pigment{ color Gray40  }
   }
}

/* SIMPLE STAND FOR THE GLOBE */
#declare GlobeStand=union{
   cylinder{
      <0,10,0>,<0,9.8,0>,3.5
      texture{ Wood1 rotate y*45 }
   }
   cylinder{
      <0,9.8,0>,<0,0,0>,0.75
      texture{ Wood1 rotate x*90 }
   }
}
/* GLOBE */
#declare Globe=union{
   sphere{
      <0,0,0>,4
      pigment{
         image_map{
            gif "fract003.gif"
            interpolate 2
            map_type 1
         }
      }
      normal{
         bump_map{
          gif "fract003.gif"
            map_type 1
            bump_size 10
         }
      }
      finish{ ambient RoomAmbiance+0.1 }
      rotate y*0
   }
   union{
      cylinder{ <0,-5,0>,<0,5,0>,0.2 }
      sphere{ <0,0,0>,0.2 scale <1,2.5,1> translate <0,5,0>}
      sphere{ <0,0,0>,0.2 scale <1,2.5,1> translate <0,-5,0>}
      torus{
         5,0.45
         scale <1,0.2,1>
         clipped_by{ plane {x,0} }
         rotate x*90
      }
      rotate z*18
      texture{ Silver1 }
   }
   union{
      cylinder{ <0,-5,0>,<0,-6,0>,0.3 }
      sphere{ <0,0,0>,0.3 scale <1,1.5,1> translate <0,-5,0> }
      cone{ <0,-6,0>,0.3,<0,-7,0>,3 }
      texture{ Silver1 }
   }
}

/* PICTURE */
#declare HEdge=union{
   triangle{ <-10,-8,-1>,<10,-8,-1>,<-9,-7,0> }
   triangle{ <9,-7,0>,<10,-8,-1>,<-9,-7,0> }
}
#declare VEdge=union{
   triangle{ <-10,-8,-1>,<-10,8,-1>,<-9,7,0> }
   triangle{ <-10,-8,-1>,<-9,-7,0>,<-9,7,0> }
}
#declare Frame=union{
   object{ HEdge }
   object{ HEdge rotate z*180 }
   object{ VEdge }
   object{ VEdge rotate z*180 }
   texture{ Brass_Texture }
}
#declare Image=union{
   triangle{ <-9,-7,0>,<9,-7,0>,<9,7,0> }
   triangle{ <-9,-7,0>,<9,7,0>,<-9,7,0> }
   pigment{
      image_map{
         gif "image.gif"      // This is one of my first traced pictures
         interpolate 2        // cropped and fit to size.
      }
      scale <18,14,1>
      translate <-9,-7,0>
   }
}
#declare Picture=union{
   object{ Image }
   object{ Frame }
}
